{
  "type": "record",
  "Aspect": {
    "name": "dataHubOAuthClientKey",
    "keyForEntity": "dataHubOAuthClient",
    "entityCategory": "internal",
    "entityAspects": [
      "dataHubOAuthClientInfo"
    ]
  },
  "name": "DataHubOAuthClientKey",
  "namespace": "com.linkedin.pegasus2avro.metadata.key",
  "fields": [
    {
      "type": "string",
      "name": "id",
      "doc": "Unique OAuth client ID"
    }
  ],
  "doc": "Key for a DataHub OAuth Client (an OAuth2 registered client for the authorization server)"
}